function [kmax, min_m, max_m, approx_type, annotation, stopeval] = param_simulation()
% Load simulation parameters.

kmax = 4;					% Maximum value of the order that the algorithm will test.
min_m = 5;                  % Dimension of the smallest and largest approximation spaces that the algorithm will consider.
max_m = 30;                 %    min_m should be larger than kmax.
approx_type = 'trigo';      % Type of approximation space. Possible values: 'histo' (histogram, not recommended) / 'trigo' (trigonometric)

stopeval = 1e5;             % Number of steps after which CMAES should stop.
% stopeval is a crucial parameter. It determines the execution time and the
% precision of the minimization algorithm. Taking it too small will make
% the algorithm unable to get accurate estimators, which will result in an
% overestimation of the order (if the algorithm returns kmax as the
% estimated order, it is likely you didn't take stopeval large enough).
% Taking it too large (more than 2e5) can make the algorithm run for days.

annotation = ['CMAfixed(' num2str(stopeval) ')'];      % Annotation to the title (misc remarks...)

% Check parameters' validity.
if kmax >= min_m
	disp(['WARNING : min_m too low. Changed value to ' num2str(kmax+1)]);
	min_m = kmax + 1;
end
